<TS language="eu_ES" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Sortu helbide berria</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Berria</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopiatu hautatutako helbidea sistemaren arbelera</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiatu</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Ezabatu aukeratutako helbideak listatik</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Ezabatu</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopiatu &amp;Etiketa</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editatu</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiketa</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Helbidea</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(etiketarik ez)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Pasahitza dialogoa</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Sartu pasahitza</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Pasahitz berria</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Errepikatu pasahitz berria</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Enkriptatu zorroa</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Eragiketa honek zorroaren pasahitza behar du zorroa desblokeatzeko.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Desblokeatu zorroa</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Aldatu pasahitza</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Sartu zorroaren pasahitz zaharra eta berria.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Berretsi zorroaren enkriptazioa</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Seguru zaude nahi duzula zure diruzorroa enkriptatu?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Zorroa enkriptatuta</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>GARRANTZITSUA: Aurreko seguritate-kopiak ordeztuko dire berriekin, enkriptatutak. Segurtasun arrazoigaitik, aurreko kopiak ezin dira erabili hasiko zarenean zure diruzorro enkriptatu berriarekin.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Zorroaren enkriptazioak huts egin du</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Zorroaren enkriptazioak huts egin du barne-errore baten ondorioz. Zure zorroa ez da enkriptatu.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Eman dituzun pasahitzak ez datoz bat.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Zorroaren desblokeoak huts egin du</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Zorroa desenkriptatzeko sartutako pasahitza okerra da.</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Gainbegiratu</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Ikusi zorroaren begirada orokorra</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Ikusi transakzioen historia</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Irten</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Irten aplikaziotik</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Aukerak...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Aldatu zorroa enkriptatzeko erabilitako pasahitza</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Artxiboa</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ezarpenak</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Laguntza</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Egunean</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Eguneratzen...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Bidalitako transakzioa</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Sarrerako transakzioa</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Zorroa &lt;b&gt;enkriptatuta&lt;/b&gt; eta &lt;b&gt;blokeatuta&lt;/b&gt; dago une honetan</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Kopurua</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kopurua</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Helbidea</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopiatu helbidea</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopiatu etiketa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(etiketarik ez)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Editatu helbidea</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiketa</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Helbidea</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Jasotzeko helbide berria</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Bidaltzeko helbide berria</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Editatu jasotzeko helbidea</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Editatu bidaltzeko helbidea</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Sartu berri den helbidea, "%1", helbide-liburuan dago jadanik.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Ezin desblokeatu zorroa.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Gako berriaren sorrerak huts egin du.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Aukerak</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Inprimakia</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Bidali txanponak</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Kopurua</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Bidali hainbat jasotzaileri batera</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Berretsi bidaltzeko ekintza</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Berretsi txanponak bidaltzea</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Ordaintzeko kopurua 0 baino handiagoa izan behar du.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(etiketarik ez)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>K&amp;opurua:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Ordaindu &amp;honi:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mezua</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiketa:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Itsatsi helbidea arbeletik</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Sartu etiketa bat helbide honetarako, eta gehitu zure helbide-liburuan</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Itsatsi helbidea arbeletik</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Zabalik %1 arte</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/konfirmatu gabe</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 konfirmazioak</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, ez da arrakastaz emititu oraindik</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>ezezaguna</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mezua</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kopurua</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Transakzioaren xehetasunak</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Panel honek transakzioaren deskribapen xehea erakusten du</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Mota</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Helbidea</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kopurua</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Zabalik %1 arte</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Konfirmatuta (%1 konfirmazio)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Sortua, baina ez onartua</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Jasota honekin: </translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Hona bidalia: </translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Ordainketa zeure buruari</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Transakzioaren egoera. Pasatu sagua gainetik konfirmazio kopurua ikusteko.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Transakzioa jasotako data eta ordua.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Transakzio mota.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Transakzioaren xede-helbidea.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Saldoan kendu edo gehitutako kopurua.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Gaur</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Aste honetan</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Hil honetan</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Azken hilean</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Aurten</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Muga...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Jasota honekin: </translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Hona bidalia: </translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Zeure buruari</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Bildua</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Beste</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Kopuru minimoa</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopiatu helbidea</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopiatu etiketa</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Mota</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiketa</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Helbidea</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kopurua</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>List commands</source>
        <translation>Komandoen lista</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Laguntza komando batean</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Birbilatzen...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Zamaketa amaitua</translation>
    </message>
    </context>
</TS>